@@ -47,7 +47,7 @@ void ExportNotesJobInterfaceTest::exportNote()
 
     auto exportNote = new ExportNotesJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
     exportNote->setListOfResource(lstInfo);
-    exportNote->setPathConfig(QLatin1String(configpath));
+    exportNote->setPathConfig(QLatin1StringView(configpath));
     file->setAbstractImportExportJob(exportNote);
     file->start();
     delete exportNote;
